@@ -325,7 +325,7 @@ class SmarterApi:
         if not user_id:
             return_message = self.send_message(message=SmarterMessage(), port="#user")
             user_id = return_message.get("user", {}).get("id")
-        existing_data = self.get_user_data(user_id=user_id, data_type_filter=data_type_id)
+        existing_data = self.get_user_data(user_id=user_id, data_type_filter=data_type_id)[0][0]
         updated_data = merge_data(old_data=existing_data, new_data=data)
         try:
             string_data = json.dumps(updated_data)
@@ -333,19 +333,19 @@ class SmarterApi:
             logger.error(f"Failed to convert user data to JSON for the user {user_id}")
             logger.error(traceback.format_exc())
             return
-        if not data_type_id:
-            insert_query = f"INSERT INTO {user_id}.static (type, sourcetype, rawdata, normdata) " \
-                           f"VALUES ({self.app_slug}, 'APP', {string_data}, '{dict()}')"
+        if data_type_id:
+            insert_query = "INSERT INTO %s.static (type, sourcetype, otherid, rawdata, normdata) " \
+                           "VALUES %s" % (user_id, (self.app_slug, 'APP', data_type_id, string_data, '{}'))
+
+            delete_query = f"DELETE FROM {user_id}.static " \
+                           f"WHERE type='{self.app_slug}' AND sourcetype='APP' AND otherid='{data_type_id}'"
+        else:
+            insert_query = "INSERT INTO %s.static (type, sourcetype, rawdata, normdata) " \
+                           "VALUES %s" % (user_id, (self.app_slug, 'APP', string_data, '{}'))
 
             delete_query = f"DELETE FROM {user_id}.static " \
                            f"WHERE type='{self.app_slug}' AND sourcetype='APP'"
 
-        else:
-            insert_query = "INSERT INTO %s.static (type, sourcetype, otherid, rawdata, normdata) " \
-                           "VALUES %s" % (user_id, ('kx7nq6s2-test-shared-pod', 'APP', data_type_id, string_data, '{}'))
-
-            delete_query = f"DELETE FROM {user_id}.static " \
-                           f"WHERE type='{self.app_slug}' AND sourcetype='APP' AND otherid='{data_type_id}'"
         self.query_data_lake(sql_query=delete_query)
         self.query_data_lake(sql_query=insert_query)
 
