@@ -13,7 +13,7 @@ class SmarterStore:
     def __init__(self, deploy_dir: str):
         self.__project_manifest = deploy_dir + '/_manifest.json'
         self.__global_path = deploy_dir + '/../_data/index.json'
-        self.__store_dir = deploy_dir + '/_data/'
+        self.__store_dir = deploy_dir + '/_data'
         self._check_store_dir()
         self.__manifest = self._load_manifest()
 
@@ -50,18 +50,24 @@ class SmarterStore:
 
     @staticmethod
     def _read_json(file_path: str) -> Any:
-        if not os.path.isfile(file_path):
+        if not os.path.isfile(file_path) or os.stat(file_path).st_size == 0:
             return
         with open(file_path, "r") as jsonFile:
-            data = json.load(jsonFile)
+            try:
+                data = json.load(jsonFile)
+            except ValueError:
+                data = {}
+                SmarterStore._write_json(file_path=file_path, data=data)
+                logger.error(f"The data file {file_path} was corrupted and has been emptied for a fix.")
         return data
 
-    def _check_store_dir(self) -> None:
-        is_exist = os.path.exists(self.__store_dir)
+    def _check_store_dir(self, user_id: str = None) -> None:
+        path = self.__store_dir if user_id is None else f"{self.__store_dir}/{user_id}"
+        is_exist = os.path.exists(path)
         if not is_exist:
-            os.makedirs(self.__store_dir)
+            os.makedirs(path)
             logger.info(
-                f"Store directory was missing and has been automatically created at the path {self.__store_dir}")
+                f"Store directory was missing and has been automatically created at the path {path}")
 
     def _update(self, original_data: Any, update_data: Any) -> dict:
         if type(original_data) != dict:
@@ -73,18 +79,20 @@ class SmarterStore:
                 original_data[k] = v
         return original_data
 
-    def _update_pattern_data(self, pattern_filename: str, new_data) -> Any:
-        if not os.path.isfile(self.__store_dir + pattern_filename):
+    def _update_pattern_data(self, path: str, new_data) -> Any:
+        if not os.path.isfile(path):
             return new_data
-        original_data = self._read_json(file_path=self.__store_dir + pattern_filename)
+        original_data = self._read_json(file_path=path)
         if type(original_data) != dict:
             return new_data
         self._update(original_data, new_data)
         return original_data
 
-    def _get_data(self, pattern: str) -> Any:
+    def _get_data(self, pattern: str, user_id: str) -> Any:
+        self._check_store_dir(user_id=user_id)
         pattern_filename = self._get_filename(pattern=pattern)
-        data = self._read_json(file_path=self.__store_dir + pattern_filename)
+        path = f"{self.__store_dir}/{user_id}/{pattern_filename}"  # !!!!!!!!!!! fixed
+        data = self._read_json(file_path=path)
         if not data:
             return None
         keys = pattern.split(".")[1:]
@@ -95,14 +103,16 @@ class SmarterStore:
             data = data[key]
         return data
 
-    def _set_pattern_data(self, pattern: str, data: Any) -> None:
+    def _set_pattern_data(self, pattern: str, data: Any, user_id: str) -> None:
+        self._check_store_dir(user_id=user_id)
         pattern_filename = self._get_filename(pattern)
         new_data = self._create_dict_from_pattern(pattern=pattern, value=data)
-        data = self._update_pattern_data(pattern_filename, new_data) if type(new_data) == dict else new_data
-        self._write_json(file_path=self.__store_dir + pattern_filename, data=data)
+        path = f"{self.__store_dir}/{user_id}/{pattern_filename}"  # !!!!!!!!!!! fixed
+        data = self._update_pattern_data(path, new_data) if type(new_data) == dict else new_data
+        self._write_json(file_path=path, data=data)
 
-    def _append_pattern_data(self, pattern: str, new_data: Any) -> None:
-        original_data = self._get_data(pattern=pattern)
+    def _append_pattern_data(self, pattern: str, new_data: Any, user_id: str) -> None:
+        original_data = self._get_data(pattern=pattern, user_id=user_id)
         if not original_data:
             original_data = new_data if type(new_data) == list else [new_data]
         else:
@@ -110,10 +120,10 @@ class SmarterStore:
                 logger.error(f"Error: Can't append {type(new_data)} to a {type(original_data)} json object")
                 return
             original_data.append(new_data)
-        self._set_pattern_data(pattern=pattern, data=original_data)
+        self._set_pattern_data(pattern=pattern, data=original_data, user_id=user_id)
 
-    def _prepend_pattern_data(self, pattern: str, new_data: Any) -> None:
-        original_data = self._get_data(pattern=pattern)
+    def _prepend_pattern_data(self, pattern: str, new_data: Any, user_id: str) -> None:
+        original_data = self._get_data(pattern=pattern, user_id=user_id)
         if not original_data:
             original_data = new_data if type(new_data) == list else [new_data]
         else:
@@ -121,33 +131,33 @@ class SmarterStore:
                 logger.error(f"Error: Can't append {type(new_data)} to a {type(original_data)} json object")
                 return
             original_data.insert(0, new_data)
-        self._set_pattern_data(pattern=pattern, data=original_data)
+        self._set_pattern_data(pattern=pattern, data=original_data, user_id=user_id)
 
     def _load_manifest(self) -> Any:
         data = self._read_json(file_path=self.__project_manifest)
         return data or {}
 
-    def get_pattern_data(self, pattern: str) -> Any:
+    def get_pattern_data(self, pattern: str, user_id: str) -> Any:
         try:
-            return self._get_data(pattern)
+            return self._get_data(pattern=pattern, user_id=user_id)
         except Exception as ex:
             logger.error(f"Failed to get pattern data. Error: {ex}")
 
-    def set_pattern_data(self, pattern: str, data: Any) -> None:
+    def set_pattern_data(self, pattern: str, data: Any, user_id: str) -> None:
         try:
-            self._set_pattern_data(pattern, data)
+            self._set_pattern_data(pattern=pattern, data=data, user_id=user_id)
         except Exception as ex:
             logger.error(f"Failed to set pattern data. Error: {ex}")
 
-    def append_pattern_data(self, pattern: str, data: Any) -> None:
+    def append_pattern_data(self, pattern: str, data: Any, user_id: str) -> None:
         try:
-            self._append_pattern_data(pattern=pattern, new_data=data)
+            self._append_pattern_data(pattern=pattern, new_data=data, user_id=user_id)
         except Exception as ex:
             logger.error(f"Failed to append pattern data. Error: {ex}")
 
-    def prepend_pattern_data(self, pattern: str, data: Any) -> None:
+    def prepend_pattern_data(self, pattern: str, data: Any, user_id: str) -> None:
         try:
-            self._prepend_pattern_data(pattern=pattern, new_data=data)
+            self._prepend_pattern_data(pattern=pattern, new_data=data, user_id=user_id)
         except Exception as ex:
             logger.error(f"Failed to prepend pattern data. Error: {ex}")
 
@@ -173,9 +183,9 @@ class SmarterStore:
         return self._get_json_property(json_obj=json_data, property_sequence=pattern, default={})
 
     def write_global_store(self, pattern: str, data: Any) -> None:
-        real_data = self._read_json(file_path=self.__global_path)
-        if type(real_data) != dict:
-            real_data = {}
+        original_data = self._read_json(file_path=self.__global_path)
+        if type(original_data) != dict:
+            original_data = {}
         new_data = self._create_dict_from_pattern(pattern=pattern, value=data)
-        data = self._update(original_data=real_data, update_data=new_data) if type(new_data) == dict else new_data
+        data = self._update(original_data=original_data, update_data=new_data) if type(new_data) == dict else new_data
         self._write_json(file_path=self.__global_path, data=data)
